@@ -1,8 +1,8 @@
-/*  $Id: french-deconjugator.cpp,v 1.6 2004/02/26 03:12:42 sarrazip Exp $
+/*  $Id: french-deconjugator.cpp,v 1.8 2005/03/13 04:03:26 sarrazip Exp $
     french-deconjugator.cpp - Analyzer of conjugated French verbs
 
     verbiste - French conjugation system
-    Copyright (C) 2003 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -118,7 +118,7 @@ displayHelp()
 
     cout <<
 "\n"
-"Copyright (C) 2003 Pierre Sarrazin <http://sarrazip.com/>\n"
+"Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>\n"
 "This program is free software; you may redistribute it under the terms of\n"
 "the GNU General Public License.  This program has absolutely no warranty.\n"
     ;
@@ -138,8 +138,6 @@ displayHelp()
 int
 main(int argc, char *argv[])
 {
-    DeconjugatorCommand cmd;
-
     #ifdef HAVE_GETOPT_LONG
 
     /*  Interpret the command-line options:
@@ -147,7 +145,7 @@ main(int argc, char *argv[])
     int c;
     do
     {
-	c = getopt_long(argc, argv, "", knownOptions, NULL);
+	c = getopt_long(argc, argv, "hv", knownOptions, NULL);
 
 	switch (c)
 	{
@@ -174,5 +172,7 @@ main(int argc, char *argv[])
 
     #endif  /* ndef HAVE_GETOPT_LONG */
 
+    DeconjugatorCommand cmd;
+
     return cmd.run(argc - optind, argv + optind);
 }
