@@ -1,8 +1,8 @@
-/*  $Id: c-api.cpp,v 1.2 2004/02/26 04:33:46 sarrazip Exp $
+/*  $Id: c-api.cpp,v 1.4 2005/03/13 04:03:26 sarrazip Exp $
     FrenchVerbDictionary.cpp - Dictionary of verbs and conjugation templates
 
     verbiste - French conjugation system
-    Copyright (C) 2003 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -239,7 +239,8 @@ int
 generateTense(VVS &conjug,
 		const char *infinitive,
 		Verbiste_Mode mode,
-		Verbiste_Tense tense)
+		Verbiste_Tense tense,
+		bool include_pronouns)
 {
     const char *tname = fvd->getVerbTemplate(infinitive);
     if (tname == NULL)
@@ -249,11 +250,9 @@ generateTense(VVS &conjug,
     	return -2;
     string radical = FrenchVerbDictionary::getRadical(infinitive, tname);
 
-    FrenchVerbDictionary::generateTense(radical, 
-					*templ, 
-					(Mode) mode, 
-					(Tense) tense, 
-					conjug);
+    fvd->generateTense(radical, *templ, (Mode) mode, (Tense) tense, conjug,
+			include_pronouns,
+			fvd->isVerbStartingWithAspirateH(infinitive));
     return 0;
 }
 
@@ -261,12 +260,13 @@ generateTense(VVS &conjug,
 Verbiste_PersonArray
 verbiste_conjugate(const char *infinitive_verb, 
 			const Verbiste_Mode mode,
-			const Verbiste_Tense tense)
+			const Verbiste_Tense tense,
+			int include_pronouns)
 {
     VVS tenseConjug;
-    if (generateTense(tenseConjug, infinitive_verb, mode, tense) != 0)
+    if (generateTense(tenseConjug, infinitive_verb, mode, tense,
+						include_pronouns != 0) != 0)
 	return NULL;
-    //return createPersonNumberArray(tenseConjug);
 
     size_t numPersons = tenseConjug.size();
     Verbiste_PersonArray personArray =
